==> opennms-services-20.0.0-20170308.055336-108-sources.jar: org/opennms/netmgt/collectd/DefaultResourceTypeMapper.java <==
/*******************************************************************************
 * This file is part of OpenNMS(R).
 *
 * Copyright (C) 2017-2017 The OpenNMS Group, Inc.
 * OpenNMS(R) is Copyright (C) 1999-2017 The OpenNMS Group, Inc.
 *
 * OpenNMS(R) is a registered trademark of The OpenNMS Group, Inc.
 *
 * OpenNMS(R) is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published
 * by the Free Software Foundation, either version 3 of the License,
 * or (at your option) any later version.
 *
 * OpenNMS(R) is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with OpenNMS(R).  If not, see:
 *      http://www.gnu.org/licenses/
 *
 * For more information contact:
 *     OpenNMS(R) Licensing <license@opennms.org>
 *     http://www.opennms.org/
 *     http://www.opennms.com/
 *******************************************************************************/

package org.opennms.netmgt.collectd;

import javax.annotation.PostConstruct;

import org.opennms.netmgt.collection.adapters.ResourceTypeMapper;
import org.opennms.netmgt.config.api.ResourceTypesDao;
import org.springframework.beans.factory.annotation.Autowired;

public class DefaultResourceTypeMapper {

    @Autowired
    private ResourceTypesDao resourceTypesDao;

    @PostConstruct
    public void registerWithTypeMapper() {
        ResourceTypeMapper.getInstance().setResourceTypeMapper(
                (type) -> resourceTypesDao.getResourceTypeByName(type));
    }
}

==> opennms-services-23.0.0-20180825.124336-72-sources.jar: org/opennms/netmgt/collectd/DefaultResourceTypeMapper.java <==
/*******************************************************************************
 * This file is part of OpenNMS(R).
 *
 * Copyright (C) 2017-2017 The OpenNMS Group, Inc.
 * OpenNMS(R) is Copyright (C) 1999-2017 The OpenNMS Group, Inc.
 *
 * OpenNMS(R) is a registered trademark of The OpenNMS Group, Inc.
 *
 * OpenNMS(R) is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published
 * by the Free Software Foundation, either version 3 of the License,
 * or (at your option) any later version.
 *
 * OpenNMS(R) is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with OpenNMS(R).  If not, see:
 *      http://www.gnu.org/licenses/
 *
 * For more information contact:
 *     OpenNMS(R) Licensing <license@opennms.org>
 *     http://www.opennms.org/
 *     http://www.opennms.com/
 *******************************************************************************/

package org.opennms.netmgt.collectd;

import javax.annotation.PostConstruct;

import org.opennms.netmgt.collection.api.ResourceTypeMapper;
import org.opennms.netmgt.config.api.ResourceTypesDao;
import org.springframework.beans.factory.annotation.Autowired;

public class DefaultResourceTypeMapper {

    @Autowired
    private ResourceTypesDao resourceTypesDao;

    @PostConstruct
    public void registerWithTypeMapper() {
        ResourceTypeMapper.getInstance().setResourceTypeMapper(
                (type) -> resourceTypesDao.getResourceTypeByName(type));
    }
}
